@@ -8,6 +8,9 @@
  * \param res: return matrix, indicatrics of size nxsum(nblev)
  * \param n,m size of matrix data.
  * 
+ *
+
+
  */
 
 void matind(int * nblev,int * data,int * res, int * n, int * m,int * k)
@@ -20,8 +23,11 @@ void matind(int * nblev,int * data,int * res, int * n, int * m,int * k)
       /* for all individuals ... */
       for(i = 0; i< *n; i++)
 	{
-	  /*	  res[i,(curr_col_in_res+ data[i,j] -1)] ++;*/
-	  res[i + (*n)*(curr_col_in_res+ data[i+ (*n)*j] -1)] ++;	  
+	  if((i + (*n)*(curr_col_in_res+ data[i+ (*n)*j] -1)) >= 0)
+	    {
+	      /*	  res[i,(curr_col_in_res+ data[i,j] -1)] ++;*/
+	      res[i + (*n)*(curr_col_in_res+ data[i+ (*n)*j] -1)] ++;	  
+	    }
 	}
       curr_col_in_res  = curr_col_in_res + nblev[j];
     }
